@@ -23,6 +23,7 @@ class CommandType
   ARRAY_GET_RANK = 21
   ARRAY_SET_ITEM = 22
   ARRAY = 23
+  RETRIEVE_ARRAY = 24
 
   def self.get_name(command_number)
     case command_number
@@ -74,6 +75,8 @@ class CommandType
       return 'ARRAY_SET_ITEM'
     when 23
       return 'ARRAY'
+    when 24
+      return 'RETRIEVE_ARRAY'
     end
   end
 end
\ No newline at end of file
